import subprocess
import os
import imp

PLATFORM_ROOT_PATH = '/usr/share/sonic/device'
SONIC_CFGGEN_PATH = '/usr/local/bin/sonic-cfggen'
HWSKU_KEY = 'DEVICE_METADATA.localhost.hwsku'
PLATFORM_KEY = 'DEVICE_METADATA.localhost.platform'
MODULE_NAME = "sfputil"
CLASS_NAME = "SfpUtil"


def get_platform_and_hwsku():
    try:
        proc = subprocess.Popen([SONIC_CFGGEN_PATH, '-H', '-v', PLATFORM_KEY],
                                stdout=subprocess.PIPE,
                                shell=False,
                                stderr=subprocess.STDOUT)
        stdout = proc.communicate()[0]
        proc.wait()
        platform = stdout.rstrip('\n')

        proc = subprocess.Popen([SONIC_CFGGEN_PATH, '-d', '-v', HWSKU_KEY],
                                stdout=subprocess.PIPE,
                                shell=False,
                                stderr=subprocess.STDOUT)
        stdout = proc.communicate()[0]
        proc.wait()
        hwsku = stdout.rstrip('\n')
    except OSError, e:
        raise OSError("Cannot detect platform")

    return (platform, hwsku)


def load_platform_util(module_name, class_name):

    # Get platform and hwsku
    (platform, hwsku) = get_platform_and_hwsku()

    # Load platform module from source
    platform_path = "/".join([PLATFORM_ROOT_PATH, platform])

    try:
        module_file = "/".join([platform_path, "plugins", module_name + ".py"])
        module = imp.load_source(module_name, module_file)
    except IOError, e:
        print("Failed to load platform module '%s': %s" % (
            module_name, str(e)), True)
        return -1

    try:
        platform_util_class = getattr(module, class_name)
        platform_util = platform_util_class()
    except AttributeError, e:
        print("Failed to instantiate '%s' class: %s" %
              (class_name, str(e)), True)
        return -2

    return platform_util

PORT_START = 1
PORT_END = 128

sfputil = load_platform_util(MODULE_NAME, CLASS_NAME)
res = sfputil.reset_all()

print(res)
